@@ -11,6 +11,7 @@ from twitchbot import (
     perms,
     is_command_whitelisted,
     translate,
+    create_translate_callable,
 )
 
 
@@ -22,7 +23,7 @@ from twitchbot import (
 #             msg=f'channel: {c.name}, viewers: {c.chatters.viewer_count}, is_mod: {c.is_mod}, is_live: {c.live}')
 
 
-@Command('commands', context=CommandContext.BOTH, help='lists all commands, add -a or -alias to list aliases')
+@Command('commands', context=CommandContext.BOTH, help=create_translate_callable('builtin_command_help_message_commands'))
 async def cmd_commands(msg: Message, *args):
     include_aliases = '-a' in args or '-alias' in args
     custom_commands = ', '.join(map(attrgetter('name'), get_all_custom_commands(msg.channel_name)))
@@ -54,7 +55,7 @@ async def cmd_commands(msg: Message, *args):
         await msg.reply(whisper=True, msg=translate('command_custom', custom_commands=custom_commands))
 
 
-@Command(name='help', syntax='<command>', help='gets the help text for a command')
+@Command(name='help', syntax='<command>', help=create_translate_callable('builtin_command_help_message_help'))
 async def cmd_help(msg: Message, *args):
     if not args:
         raise InvalidArgumentsError(reason=translate('missing_required_arguments'), cmd=cmd_help)
@@ -66,7 +67,7 @@ async def cmd_help(msg: Message, *args):
     await msg.reply(msg=translate('help_success', fullname=cmd.fullname, syntax=cmd.syntax, help=cmd.help))
 
 
-@Command(name='findperm', syntax='<command>', help='finds a permission for a given command')
+@Command(name='findperm', syntax='<command>', help=create_translate_callable('builtin_command_help_message_findperm'))
 async def cmd_find_perm(msg: Message, *args):
     if not args:
         raise InvalidArgumentsError(reason=translate('missing_required_arguments'), cmd=cmd_find_perm)
